"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLibraryNameFromCwd = exports.camelCase = exports.entriesToHtml = exports.entriesToNamedEntries = exports.toCommonJsExternal = void 0;
const fs_1 = __importDefault(require("fs"));
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const path_1 = __importDefault(require("path"));
function toCommonJsExternal(deps) {
    return Object.fromEntries(deps.map((depName) => [depName, `commonjs2 ${depName}`]));
}
exports.toCommonJsExternal = toCommonJsExternal;
function entriesToNamedEntries(entry) {
    return typeof entry === 'string'
        ? { [path_1.default.basename(entry).replace(/\.(jsx?|tsx?)$/, '')]: entry }
        : Array.isArray(entry)
            ? Object.fromEntries(entry.map((entryPath) => [
                path_1.default.basename(entryPath).replace(/\.(jsx?|tsx?)$/, ''),
                entryPath,
            ]))
            : entry;
}
exports.entriesToNamedEntries = entriesToNamedEntries;
function entriesToHtml(entries) {
    return Array.from(Object.entries(entries).map(([name, entryPath]) => {
        let template = 'auto';
        for (const ext of ['.html', '.ejs']) {
            try {
                const maybeTemplatePath = entryPath.replace(/\.(jsx?|tsx?)$/, ext);
                fs_1.default.statSync(maybeTemplatePath);
                template = maybeTemplatePath;
                break;
            }
            catch (e) {
            }
        }
        return new html_webpack_plugin_1.default({
            filename: `${name}.html`,
            template,
            chunks: [name],
        });
    }));
}
exports.entriesToHtml = entriesToHtml;
function camelCase(str) {
    return str
        .split(/[\W_]+/)
        .filter(Boolean)
        .map(([first, ...word]) => first.toUpperCase() + word.join(''))
        .join('');
}
exports.camelCase = camelCase;
function getLibraryNameFromCwd(cwd) {
    const { name, productName } = require(path_1.default.join(cwd, 'package.json'));
    return camelCase(productName || name);
}
exports.getLibraryNameFromCwd = getLibraryNameFromCwd;
//# sourceMappingURL=util.js.map